﻿using System;
using System.Collections.Generic;

namespace PSFinancials.TaskManager600
{
    public class ServiceProvider
    {
        #region Members

        private Dictionary<Type, object> _services;

        #endregion

        #region Constructors

        /// <summary>
        /// Creates a new instance of ServiceProvider.
        /// </summary>
        public ServiceProvider()
        {
            this._services = new Dictionary<Type, object>();
        }

        #endregion

        #region Methods

        /// <summary>
        /// Gets a service from the provider.
        /// </summary>
        /// <typeparam name="T">The type of service to get.</typeparam>
        /// <returns>The service.</returns>
        public T GetService<T>() where T : class
        {
            object result;
            if (this._services.TryGetValue(typeof(T), out result) == false)
                return default(T);

            return (T)result;
        }

        /// <summary>
        /// Registers a new service.
        /// </summary>
        /// <typeparam name="T">The type of service to register.</typeparam>
        /// <param name="service">The service to register.</param>
        public void RegisterService<T>(T service) where T : class
        {
            if (service == null)
                throw new ArgumentNullException("service");

            this._services.Add(typeof(T), service);
        }

        #endregion
    }
}
