﻿using PSFNetObjects;

namespace Shared
{
    /// <summary>
    /// Common interface to be implemented by classes that can provide access to a database.
    /// </summary>
    /// <remarks>
    /// Note that the session and business object properties make use of the provided interfaces (IPSFB_Ledgers rather than PSFBO_Ledgers), so that
    /// these can be substituted for any class which implements the interface (i.e. for unit tests).
    /// </remarks>
    public interface IDatabaseAccess
    {
        #region Properties

        /// <summary>
        /// Gets the current session object.
        /// </summary>
        IPSFSession Session { get; }

        /// <summary>
        /// Initialise session
        /// </summary>
        /// <param name="isUserWa"></param>
        /// <param name="server"></param>
        /// <param name="database"></param>
        /// <param name="user"></param>
        /// <param name="companyCode"></param>
        /// <param name="password"></param>
        /// <returns></returns>
        bool InitialiseSession(bool isUserWa, string server, string database, string user, string companyCode, string password);

        #endregion
    }
}
